@@ -84,7 +84,24 @@ class Order:
 
         return f"<{self.__class__.__name__} {id(self)}>"
 
-    def __repr__(self):
+    def repr(self, **fields) -> str:
+        """
+        Helper for __repr__
+        """
+
+        field_strings = []
+        at_least_one_attached_attribute = False
+
+        for key, field in fields.items():
+            field_strings.append(f'{key}={field!r}')
+            at_least_one_attached_attribute = True
+
+        if at_least_one_attached_attribute:
+            return f"<{self.__class__.__name__}({','.join(field_strings)})>"
+
+        return f"<{self.__class__.__name__} {id(self)}>"
+
+    def to_string(self):
         return self.repr(
             id=self.get_id(),
             order_reference=self.get_order_reference(),
@@ -97,3 +114,6 @@ class Order:
             amount_target_symbol=self.get_amount_target_symbol(),
             amount_trading_symbol=self.get_amount_trading_symbol()
         )
+
+    def __repr__(self):
+        return self.to_string()
