@@ -4,6 +4,7 @@ from enum import Enum
 class OrderStatus(Enum):
     SUCCESS = 'SUCCESS'
     PENDING = 'PENDING'
+    TO_BE_SENT = "TO_BE_SENT"
     FAILED = "FAILED"
     CANCELED = "CANCELED"
     CLOSED = "CLOSED"
@@ -19,6 +20,20 @@ class OrderStatus(Enum):
 
         raise ValueError("Could not convert value to OrderStatus")
 
+    @staticmethod
+    def from_value(value):
+
+        if isinstance(value, OrderStatus):
+            for order_status in OrderStatus:
+
+                if value == order_status:
+                    return order_status
+        elif isinstance(value, str):
+            return OrderStatus.from_string(value)
+
+        raise ValueError("Could not convert value to OrderStatus")
+
+
     def equals(self, other):
 
         if other is None:
